<h1>Tiquations</h1>

<h2>Documentation</h2>
<p>I have created a website using wix but it's really not that great. The easiest way to go about reading documentation is to type tiquations.help() in your console.</p>

<h2>Help commands</h2>
<ul>
<li>tiquations.help()</li>
<li>constants.variables()</li>
<li>tiquations.version()</li>
</ul>

<h2>Equations</h2>
<ul>
<li>Quadratic equation</li>
<li>Mathematical sequence equations</li>
<li>Cosine Rules for angles and sides</li>
<li>Distance/Speed/Time</li>
<li>Force/Mass/Acceleration</li>
<li>Weight/Mass/Gravitational field strength</li>
<li>Circle area/diameter/circumference</li>
<li>Delta Velocity/Time taken/Acceleration</li>
<li>Force/Area/Pressure</li>
<li>Cylinder Volume/Surface Area</li>
<li>Trapezoid Area/Height/Surface Area</li>
<li>Pythagoras' Theorum</li>
<li>Energy/Charge/Potential difference</li>
<li>Power/Current/Potential difference</li>
<li>Power/Energy/Time</li>
<li>Orbital speed/Radius/Time taken</li>
</ul>
